@@ -8,7 +8,7 @@ import random
 from translit import slugify
 
 def db(name = None):
-    """name is key in settings.COUCHDB. If None, returns default database.
+    """name is a key in settings.COUCHDB. If None, returns default database.
     Examples::
     
       settings.COUCHDB = {
@@ -98,7 +98,7 @@ def design_docs(db):
 
 
 def view_iterator(db, view, **kwargs):
-    """Iterator helper. You may call this, when you need to iterate over a very large number of rows. This function will automatically split requests by 300 result rows, accurate handling ``start_docid``.
+    """Iterator helper. You may call this when you need to iterate over a very large number of rows. This function will automatically split requests in 300 result rows, accurate handling ``start_docid``.
 
     Example::
     
@@ -153,7 +153,7 @@ def generate_id(db, prefix, suffix_length = 12, id_string = '%s%s'):
     return key
 
 def generate_doc(db, prefix, suffix_length = 12, id_string = '%s%s', max_retry = 100, data = {}):
-    """Generate doc with unique ID, based on provided prefix and random suffix. Retries on duplicate.
+    """Generate doc with unique ID based on provided prefix and random suffix. Retries on duplicate.
     **Deprecated since couchdbcurl.client.Document.create() method.**
     """
     
@@ -220,7 +220,7 @@ class CouchMiddleware:
     def process_request(self, request):
         for dbname in settings.COUCHDB:
             setattr(request, dbname, db(dbname))
-            request._db = db
+        request._db = db
 
         
         
